@@ -35,7 +35,7 @@ class FloatApprox(JestspectationBase):
         if magnitude is None and percent is None:
             raise ValueError(
                 "One of magnitude or percent must be specified")
-        if magnitude is None and percent is None:
+        if magnitude is not None and percent is not None:
             raise ValueError(
                 "Only one of magnitude or percent can be specified")
         if percent is not None and value == 0:
@@ -76,7 +76,7 @@ class FloatApprox(JestspectationBase):
                 return False
         return True
 
-    def get_diff(self, other) -> list[str]:
+    def get_diff(self, other, other_is_lhs: bool) -> list[str]:
         if not isinstance(other, (int, float)):
             head = "Type mismatch"
             err = f"Received object of type {type(other).__name__}"
